mod matrix;

use axum::{response::Redirect, routing::any, Extension, Router};
use tower_http::{services::ServeDir, trace::TraceLayer};

use std::path::PathBuf;

pub fn app(static_dir: PathBuf, redirects: &[(&'static str, &'static str)]) -> Router {
    let mut app = Router::new().nest("/", matrix::router());

    for (path, url) in redirects.iter() {
        app = app.route(path, any(|| async { Redirect::permanent(url) }))
    }

    app.fallback_service(ServeDir::new(static_dir.clone()))
        .layer(Extension(static_dir))
        .layer(TraceLayer::new_for_http())
}
